@@ -47,7 +47,7 @@ def Create_SeedCacheFile(p_szSeedName, p_nNullValueCount=0):
         for n in range(0, 100):
             buf.append(random_ascii_letters_and_digits([100, ]) + "\n")
         if p_nNullValueCount > 0:
-            for n in range(0,p_nNullValueCount):
+            for n in range(0, p_nNullValueCount):
                 m_nPos = random.randint(0, 100 - 1)
                 buf[m_nPos] = "\n"
         seed_file = os.path.join(os.environ["SQLCLI_HOME"], "data", "seed_string.100")
@@ -59,7 +59,7 @@ def Create_SeedCacheFile(p_szSeedName, p_nNullValueCount=0):
         for n in range(0, 1000):
             buf.append(random_ascii_letters_and_digits([100, ]) + "\n")
         if p_nNullValueCount > 0:
-            for n in range(0,p_nNullValueCount):
+            for n in range(0, p_nNullValueCount):
                 m_nPos = random.randint(0, 1000 - 1)
                 buf[m_nPos] = "\n"
         seed_file = os.path.join(os.environ["SQLCLI_HOME"], "data", "seed_string.1K")
@@ -406,7 +406,7 @@ def get_final_string(p_row_struct):
     return m_Result
 
 
-def Create_file(p_filename, p_formula_str, p_rows, p_options):
+def Create_file(p_filetype, p_filename, p_formula_str, p_rows, p_options):
     try:
         m_producer = None
         m_topicname = None
@@ -414,40 +414,39 @@ def Create_file(p_filename, p_formula_str, p_rows, p_options):
         m_HDFS_Handler = None
         m_filename = None
 
-        if p_filename.startswith('mem://'):
+        if p_filetype.upper() == "MEM":
             m_fs = fs.open_fs('mem://')
-            m_filename = p_filename[len('mem://'):]
+            m_filename = p_filename
             m_output = m_fs.open(m_filename, 'w')
-        elif p_filename.startswith('file://'):
+        elif p_filetype.upper() == "FS":
             m_fs = fs.open_fs('./')
-            m_filename = p_filename[len('file://'):]
+            m_filename = p_filename
             m_output = m_fs.open(m_filename, 'w')
-        elif p_filename.startswith('kafka://'):
+        elif p_filetype.upper() == "KAFKA":
             if p_options["KAFKA_SERVERS"] is None or len(p_options["KAFKA_SERVERS"].strip()) == 0:
                 raise SQLCliException("Please set KAFKA_SERVERS first")
             m_producer = KafkaProducer(bootstrap_servers=p_options["KAFKA_SERVERS"])
-            m_topicname = p_filename[len('kafka://'):]
-        elif p_filename.startswith('hdfs://'):
-            if p_options["HDFS_WEBFSURL"] is None or len(p_options["HDFS_WEBFSURL"].strip()) == 0:
-                raise SQLCliException("Please set HDFS_WEBFSURL first")
-            if p_options["HDFS_WEBFSROOT"] is None or len(p_options["HDFS_WEBFSROOT"].strip()) == 0:
-                raise SQLCliException("Please set HDFS_WEBFSROOT first")
-            m_filefullname = p_filename[len('hdfs://'):]
-            m_filename = os.path.basename(m_filefullname)
-            m_pathname = os.path.join(p_options["HDFS_WEBFSROOT"], os.path.dirname(m_filefullname))
-            m_HDFS_Handler = Client(p_options["HDFS_WEBFSURL"],
-                                    m_pathname,
+            m_topicname = p_filename
+        elif p_filetype.upper() == "HDFS":
+            # HDFS 文件格式： http://node:port/xx/yy/cc.dat
+            # 注意这里的node和port都是webfs端口，不是rpc端口
+            m_Protocal = p_filename.split("://")[0]
+            m_NodePort = p_filename[len(m_Protocal)+3:].split("/")[0]
+            m_WebFSURL = m_Protocal + "://" + m_NodePort
+            m_WebFSDir, m_filename = os.path.split(p_filename[len(m_WebFSURL):])
+            m_HDFS_Handler = Client(m_WebFSURL,
+                                    m_WebFSDir,
                                     proxy=None, session=None)
         else:
             raise SQLCliException("Unknown file format.")
 
         m_row_struct = parse_formula_str(p_formula_str)
         buf = []
-        if p_filename.startswith('hdfs://'):            # 处理HDFS文件写入
+        if p_filetype.upper() == "HDFS":              # 处理HDFS文件写入
             with m_HDFS_Handler.write(m_filename) as m_output:
                 for i in range(0, p_rows):
                     m_output.write((get_final_string(m_row_struct) + "\n").encode())
-        elif p_filename.startswith('kafka://'):        # 处理Kafka数据写入
+        elif p_filetype.upper() == "KAFKA":           # 处理Kafka数据写入
             for i in range(0, p_rows):
                 m_producer.send(m_topicname, get_final_string(m_row_struct).encode())
             m_producer.flush()
@@ -470,65 +469,61 @@ def Create_file(p_filename, p_formula_str, p_rows, p_options):
     return
 
 
-def Convert_file(p_srcfilename, p_dstfilename, p_options):
+def Convert_file(p_srcfileType, p_srcfilename, p_dstfileType, p_dstfilename):
     try:
         global g_MemoryFSHandler
-        if p_srcfilename.startswith('mem://'):
+        if p_srcfileType.upper() == "MEM":
             m_srcFSType = "MEM"
             if g_MemoryFSHandler is None:
                 g_MemoryFSHandler = fs.open_fs('mem://')
                 m_srcFS = g_MemoryFSHandler
             else:
                 m_srcFS = g_MemoryFSHandler
-            m_srcFileName = p_srcfilename[len('mem://'):]
-        elif p_srcfilename.startswith('file://'):
+            m_srcFileName = p_srcfilename
+        elif p_srcfileType.upper() == "FS":
             m_srcFSType = "FS"
             m_srcFS = fs.open_fs('./')
-            m_srcFileName = p_srcfilename[len('file://'):]
-        elif p_srcfilename.startswith('hdfs://'):
+            m_srcFileName = p_srcfilename
+        elif p_srcfileType.upper() == "HDFS":
             m_srcFSType = "HDFS"
-            m_srcFullFileName = p_srcfilename[len('hdfs://'):]
-            m_srcFileName = os.path.basename(m_srcFullFileName)
-            if p_options["HDFS_WEBFSURL"] is None or len(p_options["HDFS_WEBFSURL"].strip()) == 0:
-                raise SQLCliException("Please set HDFS_WEBFSURL first")
-            if p_options["HDFS_WEBFSROOT"] is None or len(p_options["HDFS_WEBFSROOT"].strip()) == 0:
-                raise SQLCliException("Please set HDFS_WEBFSROOT first")
-            m_srcPathName = os.path.join(p_options["HDFS_WEBFSROOT"], os.path.dirname(m_srcFullFileName))
-            m_srcFS = Client(p_options["HDFS_WEBFSURL"], m_srcPathName, proxy=None, session=None)
+            m_srcFullFileName = p_srcfilename
+            m_Protocal = m_srcFullFileName.split("://")[0]
+            m_NodePort = m_srcFullFileName[len(m_Protocal)+3:].split("/")[0]
+            m_WebFSURL = m_Protocal + "://" + m_NodePort
+            m_WebFSDir, m_srcFileName = os.path.split(m_srcFullFileName[len(m_WebFSURL):])
+            m_srcFS = Client(m_WebFSURL, m_WebFSDir, proxy=None, session=None)
         else:
             m_srcFS = None
             m_srcFileName = None
             m_srcFSType = "Not Supported"
 
-        if p_dstfilename.startswith('mem://'):
+        if p_dstfileType.upper() == "MEM":
             m_dstFSType = "MEM"
             if g_MemoryFSHandler is None:
                 g_MemoryFSHandler = fs.open_fs('mem://')
                 m_dstFS = g_MemoryFSHandler
             else:
                 m_dstFS = g_MemoryFSHandler
-            m_dstFileName = p_dstfilename[len('mem://'):]
-        elif p_dstfilename.startswith('file://'):
+            m_dstFileName = p_dstfilename
+        elif p_dstfileType.upper() == "FS":
             m_dstFSType = "FS"
             m_dstFS = fs.open_fs('./')
-            m_dstFileName = p_dstfilename[len('file://'):]
-        elif p_dstfilename.startswith('hdfs://'):
+            m_dstFileName =p_dstfilename
+        elif p_dstfileType.upper() == "HDFS":
             m_dstFSType = "HDFS"
-            m_dstFullFileName = p_dstfilename[len('hdfs://'):]
-            m_dstFileName = os.path.basename(m_dstFullFileName)
-            if p_options["HDFS_WEBFSURL"] is None or len(p_options["HDFS_WEBFSURL"].strip()) == 0:
-                raise SQLCliException("Please set HDFS_WEBFSURL first")
-            if p_options["HDFS_WEBFSROOT"] is None or len(p_options["HDFS_WEBFSROOT"].strip()) == 0:
-                raise SQLCliException("Please set HDFS_WEBFSROOT first")
-            m_dstPathName = os.path.join(p_options["HDFS_WEBFSROOT"], os.path.dirname(m_dstFullFileName))
-            m_dstFS = Client(p_options["HDFS_WEBFSURL"], m_dstPathName, proxy=None, session=None)
+            m_dstFullFileName = p_dstfilename
+            m_Protocal = m_dstFullFileName.split("://")[0]
+            m_NodePort = m_dstFullFileName[len(m_Protocal)+3:].split("/")[0]
+            m_WebFSURL = m_Protocal + "://" + m_NodePort
+            m_WebFSDir, m_dstFileName = os.path.split(m_dstFullFileName[len(m_WebFSURL):])
+            m_dstFS = Client(m_WebFSURL, m_WebFSDir, proxy=None, session=None)
         else:
             m_dstFS = None
             m_dstFileName = None
-            m_dstFSType = "Not Supported"
+            m_dstFSType = "Not Supported convert."
 
         if m_srcFSType == "Not Supported" or m_dstFSType == "Not Supported":
-            raise SQLCliException("Not supported convert.")
+            raise SQLCliException("Not supported convert. From [" + p_srcfileType + "] to [" + p_dstfileType + "]")
 
         if m_srcFSType in ('MEM', 'FS') and m_dstFSType in ('MEM', 'FS'):
             with m_srcFS.openbin(m_srcFileName, "r") as m_reader, m_dstFS.openbin(m_dstFileName, "w") as m_writer:
